diff --git a/Makefile b/Makefile
index 96eea2ff..886cda9c 100644
--- a/Makefile
+++ b/Makefile
@@ -16,52 +16,52 @@ SHELL = /bin/sh
 # Include only platform-independent builds in all
 all: docs pip src
 
-# Include all clean sub-targets in clean
-clean: clean-dist clean-docs clean-pip clean-appbundle clean-src
-
-pip: docs
-	./pkg/pip/build.sh
-
 appbundle: docs
 	./pkg/mac/build.sh
 
 appbundle-webkit: docs
 	PGADMIN4_USE_WEBKIT=1 ./pkg/mac/build.sh
 
-src:
-	./pkg/src/build.sh
-
-minimise:
-	python web/tools/minimise.py ./web
+check:
+	python web/regression/runtests.py
 
-msg-extract:
-	cd web && pybabel extract -F babel.cfg -o pgadmin/messages.pot pgadmin
+# Include all clean sub-targets in clean
+clean: clean-appbundle clean-dist clean-docs clean-pip clean-src
 
-msg-update:
-	cd web && pybabel update -i pgadmin/messages.pot -d pgadmin/translations
+clean-appbundle:
+	rm -rf mac-build/
 
-msg-compile:
-	cd web && pybabel compile -d pgadmin/translations
+clean-dist:
+	rm -rf dist/
 
-docs:
-	LC_ALL=en_US.UTF-8 LANG=en_US.UTF-8 $(MAKE) -C docs/en_US -f Makefile.sphinx html
+clean-docs:
+	LC_ALL=en_US.UTF-8 LANG=en_US.UTF-8 $(MAKE) -C docs/en_US -f Makefile.sphinx clean
 
 clean-pip:
 	rm -rf pip-build/
 
-clean-appbundle:
-	rm -rf mac-build/
-
 clean-src:
 	rm -rf src-build/
 
-clean-docs:
-	LC_ALL=en_US.UTF-8 LANG=en_US.UTF-8 $(MAKE) -C docs/en_US -f Makefile.sphinx clean
+docs:
+	LC_ALL=en_US.UTF-8 LANG=en_US.UTF-8 $(MAKE) -C docs/en_US -f Makefile.sphinx html
 
-clean-dist:
-	rm -rf dist/
+minimise:
+	python web/tools/minimise.py ./web
 
-check:
-	python web/regression/runtests.py
+msg-compile:
+	cd web && pybabel compile -d pgadmin/translations
+
+msg-extract:
+	cd web && pybabel extract -F babel.cfg -o pgadmin/messages.pot pgadmin
+
+msg-update:
+	cd web && pybabel update -i pgadmin/messages.pot -d pgadmin/translations
 
 .PHONY: docs
+
+pip: docs
+	./pkg/pip/build.sh
+
+src:
+	./pkg/src/build.sh
